__version__ = '3.1.2'

from frigg_settings.model import FriggSettings  # noqa
from frigg_settings.helpers import FileSystemWrapper  # noqa
from frigg_settings.settings import build_tasks, load_settings_file, build_settings  # noqa
